@@ -17,12 +17,23 @@ class Signature:
             description="The product ID (numeric string)",
             pattern=r"^(\d{10}|NOT_FOUND)$",
             examples=["6086499569"],
+            json_schema_extra={
+                "available_from": ["get_order_details", "list_all_product_types"]
+            }
         )
 
         model_config = ConfigDict(arbitrary_types_allowed=True, validate_assignment=True)
 
     class Output(BaseModel):
-        status: str = Field(description="Detailed product information.")
+        product_details: str = Field(
+            description=(
+                "Detailed product information of all product variants of a given product type"
+                "including item id, options, availability and price"
+            ),
+            json_schema_extra={
+                "used_by": ["exchange_delivered_order_items", "modify_pending_order_items"]
+            }
+        )
 
     plain_utterances: List[str] = [
         "Can you give me more information about this product?",
@@ -47,7 +58,7 @@ class ResponseGenerator:
     def __call__(self, workflow: Workflow, command: str, command_parameters: Signature.Input) -> CommandOutput:
         output = self._process_command(workflow, command_parameters)
         response = (
-            f'Response: {output.status}'
+            f'Response: {output.product_details}'
         )
         return CommandOutput(
             workflow_id=workflow.id,
@@ -56,5 +67,5 @@ class ResponseGenerator:
 
     def _process_command(self, workflow: Workflow, input: Signature.Input) -> Signature.Output:
         data = load_data()
-        result = GetProductDetails.invoke(data=data, product_id=input.product_id)
-        return Signature.Output(status=result) 
\ No newline at end of file
+        product_details = GetProductDetails.invoke(data=data, product_id=input.product_id)
+        return Signature.Output(product_details=product_details) 
\ No newline at end of file
