@@ -765,7 +765,7 @@ def train(workflow: fastworkflow.Workflow):
     # Only iterate through contexts defined in this specific workflow
     for ctx_name in context_set_for_training:
         ctx_cmd_list = crd.contexts[ctx_name]
-        print(f"\n\n=== Training model for workflow_folderpath: {workflow_folderpath.split('/')[-1]} and context: {ctx_name} ===\n")
+        print(f"\n=== Training model for workflow_folderpath: {workflow_folderpath.split('/')[-1]} and context: {ctx_name} ===\n")
         
         # Build the label set for this context
         train_cmds: set[str] = set(ctx_cmd_list) | core_cmds
@@ -778,20 +778,23 @@ def train(workflow: fastworkflow.Workflow):
         if ctx_name in context_utterance_cache:
             map_cmd_2_uttlist = context_utterance_cache[ctx_name]
             for cmd_name in train_cmds:
+                print(f"Getting cached utterances for context: {ctx_name}, command: {cmd_name}\n")
                 if cmd_name in map_cmd_2_uttlist:
                     utterance_command_tuples.extend(
-                        list(zip(map_cmd_2_uttlist[cmd_name], [cmd_name] * len(context_utterances)))
+                        list(zip(map_cmd_2_uttlist[cmd_name], [cmd_name] * len(map_cmd_2_uttlist[cmd_name])))
                     )
                     context_utterances |= set(map_cmd_2_uttlist[cmd_name])
-        else:
+        
+        if not context_utterances:
             context_utterance_cache[ctx_name] = {}
             for cmd_name in train_cmds:
                 if cmd_name == 'wildcard':
                     continue
+                print(f"Generating utterances for context: {ctx_name}, command: {cmd_name} ...\n")
                 context_utterance_list = _get_utterances(
                     workflow, workflow_folderpath, cmd_dir, cmd_name)            
                 utterance_command_tuples.extend(
-                    list(zip(context_utterance_list, [cmd_name] * len(context_utterances)))
+                    list(zip(context_utterance_list, [cmd_name] * len(context_utterance_list)))
                 )
                 context_utterance_cache[ctx_name][cmd_name] = context_utterance_list           
                 context_utterances |= set(context_utterance_list)
@@ -807,9 +810,11 @@ def train(workflow: fastworkflow.Workflow):
             (ancestor_utterances - context_utterances) | wildcard_utterances
         )
         utterance_command_tuples.extend(
-            list(zip(net_ancestor_plus_wildcard_utterances, ['wildcard'] * len(context_utterances)))
+            list(zip(net_ancestor_plus_wildcard_utterances, ['wildcard'] * len(net_ancestor_plus_wildcard_utterances)))
         )
             
+        print("Utterances generation complete! Beginning model pipeline training\n")
+
         # ==================================================================================
         # Original training procedure below, with only artefact paths changed to per-context
         # ==================================================================================
@@ -823,7 +828,6 @@ def train(workflow: fastworkflow.Workflow):
         tiny_tokenizer = AutoTokenizer.from_pretrained(model_name)
         tiny_model = AutoModelForSequenceClassification.from_pretrained(model_name, num_labels=num).to(device)
 
-
         model_name = "distilbert-base-uncased"
         print(f"Loading {model_name}...")
         distil_tokenizer = AutoTokenizer.from_pretrained(model_name)
